clear all
close all
%%                 AD identification, Horizontal Test                  %%

%%SINGLE DOF identification method in time domain
%%Input: Displacement and force time history from wind tunnel testing
%%Output: Aerodynamic derivatives

%Import of data from horizontal section tests, 1 wind speed, 7 frequencies

%Imported data:
%WindV - wind velocity
%rr - displacment time history
%SteadyTime - time vector
%Q - recorded self-excited forces

freq=[0.5, 0.8, 1.1, 1.4, 1.7, 2, 2.5]; %Frequencies of test motion
rho=1.17; %Air density in wind tunnel

SectionNumber=1; %Choose section number
load('SectionProperties.mat'); %Import section data
B=SectionsBHL(SectionNumber,1);
L=SectionsBHL(SectionNumber,3);

for i=1:length(freq)
load(['day 3Self-excited forces 4.9879wind spped ' num2str(freq(i)) 'Hz.mat'])
if i==1 
qstore=zeros(9000,3,length(freq));
rstore=zeros(9000,3,length(freq));
end
qstore(:,:,i)=Q(1:9000,:); %Store forces in matrix
rstore(:,:,i)=rr(1:9000,:); %Store forces in matrix

% Make 0 mean forces
for j=1:3
    clear meanvector
    meanvector=ones(9000,1);
if mean(qstore(:,j,i))>0
    meanvector=mean(qstore(:,j,i)).*meanvector;
    qstore(:,j,i)=qstore(:,j,i)-abs(meanvector);
elseif mean(qstore(:,j,i))<0
    meanvector=mean(qstore(:,j,i)).*meanvector;
    qstore(:,j,i)=qstore(:,j,i)+abs(meanvector);
end
end

end

omega=(2*pi).*freq; %Calculations in radians
dt=SteadyTime(20)-SteadyTime(19); %Time increment from input time-vector

%redefining displacment time history vectors. Row 1: y-dir, row 2: z-dir,
%row 3: angle
dth=zeros(3,9000,length(freq));

for i=1:length(freq)
    for j=1:3
        dth(j,:,i)=rstore(:,j,i);
    end
end

N=length(dth);

%Defining aerodynamic derivative vectors
P=zeros(6,length(freq));
H=zeros(6,length(freq));
A=zeros(6,length(freq));
P_star=zeros(6,length(freq));
H_star=zeros(6,length(freq));
A_star=zeros(6,length(freq));

%Create velocity and displacment matrix. 
%[(y-dir velocity) (y-dir displacement) (z-dir velocity z-dir displacment) (torsion velocity torsion displacement)]

X_U_i=zeros(N,2*3,j);
for j=1:length(freq)
    for i=1:3
        for n=1:N-2
         X_U_i(n+1,2*i-1,j)=(dth(i,n+2,j)-dth(i,n,j))/(2*dt);
         X_U_i(n,2*i,j)=dth(i,n,j);
        end
    end
end

% Calculation flutter derivatives from each test at different wind
% velocities



%Calculate reduced frequency and velocity in each direction
VV_red=WindV./(freq*B);    %Reduced wind velocity 
K_y=(B.*omega)./WindV;      %Reduced horizontal circular frequency 
K_z=(B.*omega)./WindV;       %Reduced vertical circular frequency 
K_theta=(B.*omega)./WindV;   %Reduced torsional circular frequency 

%Calculate aerodynamic derivative at each frequency point
for j=1:length(freq)
clear Q_se_U_j D_i
Q_se_U_j=qstore(:,:,j);     

%Equivalent aerodynamic derivatives:
 D_i=(X_U_i(:,(2-1:2),j)'*X_U_i(:,(2-1:2),j))\(X_U_i(:,(2-1:2),j)'*Q_se_U_j);
      
        P(1,j)=D_i(1,1);P(4,j)=D_i(2,1);
        H(5,j)=D_i(1,2);H(6,j)=D_i(2,2);
        A(5,j)=D_i(1,3);A(6,j)=D_i(2,3);


%Create matrix relationship between equivalent and true aerodynamic
%derivatives
RelMatDrag=(0.5*rho*(WindV^2)*B).*[K_y(j)/WindV 0 0 0 0 0; 
                                    0 K_theta(j)*B/WindV 0 0 0 0; 
                                    0 0 K_theta(j)^2 0 0 0; 
                                    0 0 0 (K_y(j)^2)/B 0 0;
                                    0 0 0 0 K_z(j)/WindV 0;
                                    0 0 0 0 0 (K_z(j)^2)/B];
 
RelMatLift=(0.5*rho*(WindV^2)*B).*[K_z(j)/WindV 0 0 0 0 0; 
                                    0 K_theta(j)*B/WindV 0 0 0 0; 
                                    0 0 K_theta(j)^2 0 0 0; 
                                    0 0 0 (K_z(j)^2)/B 0 0;
                                    0 0 0 0 K_y(j)/WindV 0;
                                    0 0 0 0 0 (K_y(j)^2)/B];
 
RelMatMoment=(0.5*rho*(WindV^2)*B^2).*[K_z(j)/WindV 0 0 0 0 0; 
                                        0 K_theta(j)*B/WindV 0 0 0 0; 
                                        0 0 K_theta(j)^2 0 0 0; 
                                        0 0 0 (K_z(j)^2)/B 0 0;
                                        0 0 0 0 K_y(j)/WindV 0;
                                        0 0 0 0 0 (K_y(j)^2)/B];

%Only horizontal motion
P_star(1,j)=(1/L)*P(1,j)/RelMatDrag(1,1);
P_star(4,j)=(1/L)*P(4,j)/RelMatDrag(4,4);
H_star(5,j)=(1/L)*H(5,j)/RelMatLift(5,5);
H_star(6,j)=(1/L)*H(6,j)/RelMatLift(6,6);
A_star(5,j)=(1/L)*A(5,j)/RelMatMoment(5,5);
A_star(6,j)=(1/L)*A(6,j)/RelMatMoment(6,6);
end

%Plotting
VV_red=(2*pi).*VV_red; %Plotting in Hz
        
           x = [VV_red 0];
        yP1 = [P_star(1,:) 0];
        yP4 = [P_star(4,:) 0];
        yH5 = [H_star(5,:) 0];
        yH6 = [H_star(6,:) 0];
        yA5 = [A_star(5,:) 0];
        yA6 = [A_star(6,:) 0];

        pP1 = polyfit(x,yP1,3);
        pP4 = polyfit(x,yP4,3);
        pH5 = polyfit(x,yH5,3);
        pH6 = polyfit(x,yH6,3);
        pA5 = polyfit(x,yA5,3);
        pA6 = polyfit(x,yA6,3);

        x1 = linspace(0,ceil(max(VV_red)));
        y1pP1 = polyval(pP1,x1);
        y1pP4 = polyval(pP4,x1);
        y1pA5 = polyval(pA5,x1);
        y1pA6 = polyval(pA6,x1);
        y1pH5 = polyval(pH5,x1);
        y1pH6 = polyval(pH6,x1);

        figure
        subplot(2,3,1)
        plot(x,yP1,'o')
        hold on
        plot(x1,y1pP1)
        title('P^{*}_1')
        hold off

        subplot(2,3,2)
        plot(x,yH5,'o')
        hold on
        plot(x1,y1pH5)
        title('H^{*}_5')
        hold off

        subplot(2,3,3)
        plot(x,yA5,'o')
        hold on
        plot(x1,y1pA5)
        title('A^{*}_5')
        hold off

        subplot(2,3,4)
        plot(x,yP4,'o')
        hold on
        plot(x1,y1pP4)
        title('P^{*}_4')
        hold off

        subplot(2,3,5)
        plot(x,yH6,'o')
        hold on
        plot(x1,y1pH6)
        title('H^{*}_6')
        hold off

        subplot(2,3,6)
        plot(x,yA6,'o')
        hold on
        plot(x1,y1pA6)
        title('A^{*}_6')
        hold off

        suptitle('Flutter derivatives from horizontal test')

% %Printing of figures to latex image folder:
% delete('C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_horizontal.jpg')
% delete('C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_vertical.jpg')   
% delete('C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_torsional.jpg')   
% 
% print(h10,'-djpeg','C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_horizontal.jpg')
% print(h20,'-djpeg','C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_vertical.jpg')
% print(h30,'-djpeg','C:\Users\svend\OneDrive for Business\Masteroppgave\LaTex\bilder\ADs_torsional.jpg')

% Saving ADs to matrix.
%ADs = cat(3,H_star,A_star,P_star);
%save('ADs','ADs')

% DataPath=['C:\Users\svend\OneDrive for Business\Masteroppgave\Fra Vindtunneltesting\Wind tunnel process data\Compare\twin2horizontal'];
% MatSavePath=[DataPath '.mat'];
% 
% % Redefining variables and storing for further use
% x_tw2h=x;
% yP1_tw2h=yP1;
% yP4_tw2h=yP4;
% yH5_tw2h=yH5;
% yH6_tw2h=yH6;
% yA5_tw2h=yA5;
% yA6_tw2h=yA6;
% 
% save(MatSavePath,'x_tw2h','yP1_tw2h','yP4_tw2h','yH5_tw2h','yH6_tw2h','yA5_tw2h','yA6_tw2h')