%% EXTRACT STATIC COEFFICIENTS FROM TEST DATA %%

%Choose section
load('SectionProperties.mat');
SectionNumber=1;
B=SectionsBHL(SectionNumber,1);
D=SectionsBHL(SectionNumber,2);
L=SectionsBHL(SectionNumber,3);

%In-wind data (Remember to adjust directions, horizontal and torsion need to be multiplied with -1)
load('Processed Data DayXXTestXX.mat'); %Load actual data file from extraction 

%Find max point of motion:
[num] = max(PosT(:));
[x y] = ind2sub(size(PosT),find(PosT==num));
startpoint=y(1);

[num] = min(PosT(:));
[x y] = ind2sub(size(PosT),find(PosT==num));
endpoint=y(1);

vector_length=endpoint-startpoint;

Drag_har=-DragFilt(startpoint:endpoint);
Lift_har=LiftFilt(startpoint:endpoint);
Moment_har=-MomentFilt(startpoint:endpoint);

meanvector=ones(1,length(Drag_har));
Mean_har_h=-MeanForce(1).*meanvector;
Mean_har_v=MeanForce(2).*meanvector;
Mean_har_t=-MeanForce(3).*meanvector;

VWind=V;
rho=Rho;
alpha_har=-PosT(startpoint:endpoint);
 
%Still air data
load('Processed Data Day4zerowindTest63.mat');

%Find max point of motion:
[num] = max(PosT(:));
[x y] = ind2sub(size(PosT),find(PosT==num));
startpoint=y(1);

endpoint=startpoint+vector_length;

Drag_har_0=-DragFilt(startpoint:endpoint);
Lift_har_0=LiftFilt(startpoint:endpoint);
Moment_har_0=-MomentFilt(startpoint:endpoint);
 
%Deleting means
meanvector=ones(1,length(Drag_har));
Mean_har_0_h=-MeanForce(1).*meanvector;
Mean_har_0_v=MeanForce(2).*meanvector;
Mean_har_0_t=-MeanForce(3).*meanvector;

Res_Drag_har=Drag_har-Drag_har_0+Mean_har_h-Mean_har_0_h;
Res_Lift_har=Lift_har-Lift_har_0+Mean_har_v-Mean_har_0_v;
Res_Moment_har=Moment_har-Moment_har_0+Mean_har_t-Mean_har_0_t;

%Drag coefficient
D_coeff_har=Res_Drag_har/(0.5*rho*VWind^2*D*L);

%Smoothing of graph
SmoothedValues = csaps(alpha_har,D_coeff_har,0.01,alpha_har);
D_coeff_har=SmoothedValues;

h10=figure(10);
plot(alpha_har,D_coeff_har)
grid on
title('Drag coefficient')
legend('Hardanger section','Location','southeast')
axis([-10 10 0.4 1.2])
xlabel('\alpha')
ylabel('C_D')

%Lift coefficient
L_coeff_har=Res_Lift_har/(0.5*rho*VWind^2*B*L);
%Smoothing of graph
SmoothedValues = csaps(alpha_har,L_coeff_har,0.01,alpha_har);
L_coeff_har=SmoothedValues;

h20=figure(20);
plot(alpha_har,L_coeff_har)
grid on
title('Lift coefficient')
legend('Hardanger section','Location','southeast')
axis([-10 10 -1 0.8])
xlabel('\alpha')
ylabel('C_L')

%Moment cefficient
M_coeff_har=Res_Moment_har/(0.5*rho*VWind^2*B^2*L);

%Smoothing of graph
SmoothedValues = csaps(alpha_har,M_coeff_har,0.01,alpha_har);
M_coeff_har=SmoothedValues;

h30=figure(30);
plot(alpha_har,M_coeff_har)
grid on
title('Moment coefficient')
legend('Hardanger section','Location','southeast')
axis([-10 10 -0.2 0.2])
xlabel('\alpha')
ylabel('C_M')

%Save data to file for further use
DataPath=['C:\Users\svend\OneDrive for Business\Masteroppgave\Fra Vindtunneltesting\Wind tunnel process data\Compare SC\hardanger'];
MatSavePath=[DataPath '.mat'];

save(MatSavePath,'alpha_har','D_coeff_har','L_coeff_har','M_coeff_har')






