%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Abaqus model of twin girder model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%GEOMETRY
clear all
n_el=40; %number of elements
l_girder=2.671;%[m]
l_el_girder=l_girder/n_el; %[m]
gap=0.5; %Distance between girders [m]
l_el_endplate=gap/n_el; %[m]
l_el_divplate=gap/n_el; %[m]
l_endpipe=0.005;%[m]
l_el_endpipe=l_endpipe; %[m]


%Node coordinates
node_girder1=zeros(n_el+1,4);
node_girder2=zeros(n_el+1,4);
node_girder1(:,1)=101:(100+n_el+1);
node_girder1(:,2)=0:l_el_girder:l_girder;
node_girder2(:,1)=201:(200+n_el+1);
node_girder2(:,2)=0:l_el_girder:l_girder;
node_girder2(:,3)=gap;

node_endplate1=zeros(n_el-1,4);
node_endplate1(:,1)=302:(300+n_el);
node_endplate1(:,3)=l_el_endplate:l_el_endplate:gap-l_el_endplate;

node_endpipe1=[1 -l_endpipe node_endplate1(n_el/2,3) 0];
               
node_endplate2=zeros(n_el-1,4);
node_endplate2(:,1)=402:(400+n_el);
node_endplate2(:,2)=l_girder;
node_endplate2(:,3)=l_el_endplate:l_el_endplate:gap-l_el_endplate;


node_endpipe2=[2 (l_girder+l_el_endpipe) node_endplate2(n_el/2,3) 0];

node_divplate1=zeros(n_el-1,4);
node_divplate1(:,1)=502:(500+n_el);
node_divplate1(:,2)=node_girder1(1+round(n_el/4),2);
node_divplate1(:,3)=l_el_endplate:l_el_endplate:gap-l_el_endplate;

node_divplate2=zeros(n_el-1,4);
node_divplate2(:,1)=602:(600+n_el);
node_divplate2(:,2)=node_girder1(1+2*round(n_el/4),2);
node_divplate2(:,3)=l_el_endplate:l_el_endplate:gap-l_el_endplate;

node_divplate3=zeros(n_el-1,4);
node_divplate3(:,1)=702:(700+n_el);
node_divplate3(:,2)=node_girder1(1+3*round(n_el/4),2);
node_divplate3(:,3)=l_el_endplate:l_el_endplate:gap-l_el_endplate;

%Elements
elGirder1=zeros(n_el,3);
elGirder1(:,1)=101:(100+n_el);
elGirder1(:,2)=elGirder1(:,1);
elGirder1(:,3)=elGirder1(:,1)+1;

elGirder2=zeros(n_el,3);
elGirder2(:,1)=201:(200+n_el);
elGirder2(:,2)=elGirder2(:,1);
elGirder2(:,3)=elGirder2(:,1)+1;

elEndplate1=zeros(n_el,3);
elEndplate1(:,1)=301:(300+n_el);
elEndplate1(1,2)=node_girder1(1,1);
elEndplate1(2:n_el,2)=elEndplate1(2:n_el,1);
elEndplate1(1:(n_el-1),3)=elEndplate1(1:(n_el)-1,1)+1;
elEndplate1(n_el,3)=node_girder2(1,1);

elEndpipe1=[1 1 node_endplate1(n_el/2,1)];

elEndplate2=zeros(n_el,3);
elEndplate2(:,1)=401:(400+n_el);
elEndplate2(1,2)=node_girder1(n_el+1,1);
elEndplate2(2:n_el,2)=elEndplate2(2:n_el,1);
elEndplate2(1:(n_el-1),3)=elEndplate2(1:(n_el)-1,1)+1;
elEndplate2(n_el,3)=node_girder2(n_el+1,1);

elEndpipe2=[2 node_endplate2(n_el/2,1) 2];
  
elDivplate1=zeros(n_el,3);
elDivplate1(:,1)=501:(500+n_el);
elDivplate1(1,2)=node_girder1(1,1)+round(n_el/4);
elDivplate1(2:n_el,2)=elDivplate1(2:n_el,1);
elDivplate1(1:(n_el-1),3)=elDivplate1(1:(n_el)-1,1)+1;
elDivplate1(n_el,3)=node_girder2(1,1)+round(n_el/4);

elDivplate2=zeros(n_el,3);
elDivplate2(:,1)=601:(600+n_el);
elDivplate2(1,2)=node_girder1(1,1)+2*round(n_el/4);
elDivplate2(2:n_el,2)=elDivplate2(2:n_el,1);
elDivplate2(1:(n_el-1),3)=elDivplate2(1:(n_el)-1,1)+1;
elDivplate2(n_el,3)=node_girder2(1,1)+2*round(n_el/4);

elDivplate3=zeros(n_el,3);
elDivplate3(:,1)=701:(700+n_el);
elDivplate3(1,2)=node_girder1(1,1)+3*round(n_el/4);
elDivplate3(2:n_el,2)=elDivplate3(2:n_el,1);
elDivplate3(1:(n_el-1),3)=elDivplate3(1:(n_el)-1,1)+1;
elDivplate3(n_el,3)=node_girder2(1,1)+3*round(n_el/4);

%%Create file
clc
fid = fopen('double_model_abaqus.inp','wt');    

%% Main geometry
fprintf(fid,['********************************** \n']);
fprintf(fid,['** NODES AND GEOMETRY \n']);
fprintf(fid,['********************************** \n']);

%Girder nodes
formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** GIRDER 1 NODES \n']);
fprintf(fid,[ '*NODE,NSET=GIRDER1NODES \n']);
fprintf(fid,formatSpec, node_girder1'); %print node number and coordinates
sprintf(formatSpec, node_girder1') %print in matlab window

formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** GIRDER 2 NODES \n']);
fprintf(fid,[ '*NODE,NSET=GIRDER2NODES \n']);
fprintf(fid,formatSpec, node_girder2'); %print node number and coordinates
sprintf(formatSpec, node_girder2') %print in matlab window

%End plate nodes
formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** END PLATE 1 NODES \n']);
fprintf(fid,[ '*NODE,NSET=ENDPLATE1NODES \n']);
fprintf(fid,formatSpec, node_endplate1'); %print node number and coordinates
sprintf(formatSpec, node_endplate1') %print in matlab window

formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** END PLATE 2 NODES \n']);
fprintf(fid,[ '*NODE,NSET=ENDPLATE2NODES \n']);
fprintf(fid,formatSpec, node_endplate2'); %print node number and coordinates
sprintf(formatSpec, node_endplate2') %print in matlab window

%End PIPE nodes
formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** END PIPE 1 NODES \n']);
fprintf(fid,[ '*NODE,NSET=ENDPIPE1NODES \n']);
fprintf(fid,formatSpec, node_endpipe1'); %print node number and coordinates
sprintf(formatSpec, node_endpipe1') %print in matlab window

formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** END PIPE 2 NODES \n']);
fprintf(fid,[ '*NODE,NSET=ENDPIPE2NODES \n']);
fprintf(fid,formatSpec, node_endpipe2'); %print node number and coordinates
sprintf(formatSpec, node_endpipe2') %print in matlab window


%Dividing plate nodes
formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** DIVIDING PLATE 1 NODES \n']);
fprintf(fid,[ '*NODE,NSET=DIVIDINGPLATE1NODES \n']);
fprintf(fid,formatSpec, node_divplate1'); %print node number and coordinates
sprintf(formatSpec, node_divplate1') %print in matlab window

formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** DIVIDING PLATE 2 NODES \n']);
fprintf(fid,[ '*NODE,NSET=DIVIDINGPLATE2NODES \n']);
fprintf(fid,formatSpec, node_divplate2'); %print node number and coordinates
sprintf(formatSpec, node_divplate2') %print in matlab window

formatSpec = '%.0f,%.5f,%.5f,%.5f \n'; %first number integer, then 5 dec, 5 dec, 5 dec
fprintf(fid,['** DIVIDING PLATE 3 NODES \n']);
fprintf(fid,[ '*NODE,NSET=DIVIDINGPLATE3NODES \n']);
fprintf(fid,formatSpec, node_divplate3'); %print node number and coordinates
sprintf(formatSpec, node_divplate3') %print in matlab window

%Girder elements
fprintf(fid,['** \n']);
fprintf(fid,['**GIRDER ELEMENTS \n']);
fprintf(fid,[ '*ELEMENT, TYPE=' 'B31' ', ELSET='  'GIRDERELEMENTS' '\n']);
formatSpec = '%.0f, %.0f, %.0f \n'; %all three integer
fprintf(fid,formatSpec, elGirder1');%print element number
sprintf(formatSpec, elGirder1') %print in matlab window
fprintf(fid,formatSpec, elGirder2');%print element number
sprintf(formatSpec, elGirder2') %print in matlab window


%End plate elements
fprintf(fid,['** \n']);
fprintf(fid,['**END PLATE ELEMENTS \n']);
fprintf(fid,[ '*ELEMENT, TYPE=' 'B31' ', ELSET='  'ENDPLATEELEMENTS' '\n']);
formatSpec = '%.0f, %.0f, %.0f \n'; %all three integer
fprintf(fid,formatSpec, elEndplate1');%print element number
sprintf(formatSpec, elEndplate1') %print in matlab window
fprintf(fid,formatSpec, elEndplate2');%print element number
sprintf(formatSpec, elEndplate2') %print in matlab window

%End PIPE elements
fprintf(fid,['** \n']);
fprintf(fid,['**END PIPE ELEMENTS \n']);
fprintf(fid,[ '*ELEMENT, TYPE=' 'B31' ', ELSET='  'ENDPIPEELEMENTS' '\n']);
formatSpec = '%.0f, %.0f, %.0f \n'; %all three integer
fprintf(fid,formatSpec, elEndpipe1');%print element number
sprintf(formatSpec, elEndpipe1') %print in matlab window
fprintf(fid,formatSpec, elEndpipe2');%print element number
sprintf(formatSpec, elEndpipe2') %print in matlab window

%Dividing plate elements
fprintf(fid,['** \n']);
fprintf(fid,['**Dividing PLATE ELEMENTS \n']);
fprintf(fid,[ '*ELEMENT, TYPE=' 'B31' ', ELSET='  'DIVIDINGPLATEELEMENTS' '\n']);
formatSpec = '%.0f, %.0f, %.0f \n'; %all three integer
fprintf(fid,formatSpec, elDivplate1');%print element number
sprintf(formatSpec, elDivplate1') %print in matlab window
fprintf(fid,formatSpec, elDivplate2');%print element number
sprintf(formatSpec, elDivplate2') %print in matlab window
fprintf(fid,formatSpec, elDivplate3');%print element number
sprintf(formatSpec, elDivplate3') %print in matlab window

%Create section for GIRDER
fprintf(fid,['**\n']);
fprintf(fid,['**GIRDER \n']);
fprintf(fid,[ '*BEAM GENERAL SECTION, ELSET=GIRDERELEMENTS, SECTION=GENERAL, DENSITY=0\n']);
fprintf(fid,[ '4.230e-4, 2.393e-8, 0, 2.746e-8, 4.864e-8   \n']);  %A. Iy, Izy, Iz, It
fprintf(fid,[ '0,1,0  \n']);
fprintf(fid,[ '69e9, 27e9  \n']);

%Create inertia and mass per unit length:
%Add inertia to the GIRDER beam
fprintf(fid,['**ADD BEAM INERTIA \n']);
fprintf(fid,['*BEAM ADDED INERTIA \n']);
fprintf(fid,['0.712,0,0,0,1.20698e-4,4.38182e-4,2.865e-5 \n']);%Mass per unit length,,,,I11,I22,I12

%Create section for END PIPE
fprintf(fid,['**\n']);
fprintf(fid,['**END PIPE \n']);
fprintf(fid,[ '*BEAM GENERAL SECTION, ELSET=ENDPIPEELEMENTS, SECTION=GENERAL, DENSITY=2775\n']);%Density Aluminium alloy 6061 (kg/m^3)
fprintf(fid,[ '1.225e-4, 2.331e-8, 0, 2.331e-8, 4.659e-8   \n']);  %A. Iy, Izy, Iz, It
fprintf(fid,[ '0,1,0  \n']);
fprintf(fid,[ '69e9, 27e9  \n']); %NB! Sjekk faktiske verdier for aktuell type aluminium!!


%Create section for END PLATES
fprintf(fid,['**\n']);
fprintf(fid,['**END_PLATE \n']);
fprintf(fid,[ '*BEAM GENERAL SECTION, ELSET=ENDPLATEELEMENTS, SECTION=GENERAL, DENSITY=758\n']);%Density Wood (kg/m^3)
fprintf(fid,[ '6.3e-4, 2.573e-7, 0, 4.253e-9, 1.701e-8   \n']);  %A. Iy, Izy, Iz, It
fprintf(fid,[ '1,0,0  \n']);
fprintf(fid,[ '10e9,0.6e9  \n']); %NB! Sjekk faktiske verdier for aktuell type tre!!

%Create section for DIVIDING PLATES
fprintf(fid,['**\n']);
fprintf(fid,['**END_PLATE \n']);
fprintf(fid,[ '*BEAM GENERAL SECTION, ELSET=DIVIDINGPLATEELEMENTS, SECTION=GENERAL, DENSITY=758\n']);%Density Wood (kg/m^3)
fprintf(fid,[ '4.5e-4, 9.375e-8, 0, 3.038e-9, 1.215e-8   \n']);  %A. Iy, Izy, Iz, It
fprintf(fid,[ '1,0,0  \n']);
fprintf(fid,[ '10e9,0.6e9  \n']); %NB! Sjekk faktiske verdier for aktuell type tre!!

%Release rotational DOF DIVIDING PLATES connection
fprintf(fid,['**\n']);
fprintf(fid,['**RELEASE CONNECTION ELEMENT ROTATIONAL DOF \n']);
fprintf(fid,[ '*RELEASE \n']);
fprintf(fid,[ '501,S1,M2   \n']);  %Element number, element end, Release combination code
fprintf(fid,[ '540,S2,M2   \n']);  %Element number, element end, Release combination code
fprintf(fid,[ '601,S1,M2   \n']);  %Element number, element end, Release combination code
fprintf(fid,[ '640,S2,M2   \n']);  %Element number, element end, Release combination code
fprintf(fid,[ '701,S1,M2   \n']);  %Element number, element end, Release combination code
fprintf(fid,[ '740,S2,M2   \n']);  %Element number, element end, Release combination code

%Create static step 1, gravity load on girder:
fprintf(fid,['**\n']);
fprintf(fid,['**Static step 1: Only gravity load on GIRDER. \n']);
fprintf(fid,['*STEP, AMPLITUDE=RAMP, NLGEOM, INC=5000 \n']);
fprintf(fid,[ '*STATIC  \n']);
fprintf(fid,[ '0.001, 1, 1e-8    \n']);

%Create load
fprintf(fid,[ '*DLOAD,OP=NEW \n']);
fprintf(fid,[ 'GIRDERELEMENTS, GRAV, 9.81, 0 , 0 , -1  \n']);
fprintf(fid,[ 'ENDPLATEELEMENTS, GRAV, 9.81, 0 , 0 , -1  \n']);
fprintf(fid,[ 'ENDPIPEELEMENTS, GRAV, 9.81, 0 , 0 , -1  \n']);
fprintf(fid,[ 'DIVIDINGPLATEELEMENTS, GRAV, 9.81, 0 , 0 , -1  \n']);

%Create BC's
fprintf(fid,[ '*BOUNDARY,OP=NEW  \n']);
fprintf(fid,[ '1,1,6,0   \n']);
fprintf(fid,[ '2,1,6,0   \n']);

%End step
fprintf(fid,[ '**    \n']);
fprintf(fid,[ '**   \n']);
fprintf(fid,[ '*END STEP   \n']);

%Step 2: Frequency step
fprintf(fid,['**\n']);
fprintf(fid,['**Step 4: Frequency step. \n']);
fprintf(fid,['*STEP, AMPLITUDE=RAMP, INC=5000 \n']);
fprintf(fid,[ '*FREQUENCY, NORMALIZATION=DISPLACEMENT  \n']);
fprintf(fid,[ ',,80  \n']); %Analysis up to 40Hz
%Create BC's
% fprintf(fid,[ '*BOUNDARY,OP=NEW  \n']);
% fprintf(fid,[ '1,1,4,0   \n']);
% fprintf(fid,[ '10,2,4,0   \n']);

fprintf(fid,[ '*OUTPUT, FIELD   \n']);
fprintf(fid,[ '*Node output   \n']);
fprintf(fid,[ 'U, UR   \n']);

%End step
fprintf(fid,[ '**    \n']);
fprintf(fid,[ '**   \n']);
fprintf(fid,[ '*END STEP   \n']);

%Create static step 2: Concentrated load on midpoint of girder

%Find midpoint node
midnode1=node_girder1(round(length(node_girder1)/2),1);
midnode2=node_girder2(round(length(node_girder2)/2),1);

%Define node set for midpoint node
fprintf(fid,['*NSET, NSET=MIDNODE1 \n']);
fprintf(fid,formatSpec, midnode1');%print element number
fprintf(fid,[ '\n']);
fprintf(fid,['*NSET, NSET=MIDNODE2 \n']);
fprintf(fid,formatSpec, midnode2');%print element number
fprintf(fid,[ '\n']);

fprintf(fid,['**\n']);
fprintf(fid,['**Static step 1: Concentrated load on GIRDER. \n']);
fprintf(fid,['*STEP, AMPLITUDE=RAMP, NLGEOM, INC=5000 \n']);
fprintf(fid,[ '*STATIC  \n']);
fprintf(fid,[ '0.001, 1, 1e-8    \n']);

%Create load
fprintf(fid,[ '*CLOAD,OP=NEW \n']);
fprintf(fid,['MIDNODE1,3,-50  \n']);
fprintf(fid,['MIDNODE2,3,-50  \n']);

%Create BC's
fprintf(fid,[ '*BOUNDARY,OP=NEW  \n']);
fprintf(fid,[ '1,1,4,0   \n']);
fprintf(fid,[ '2,2,4,0   \n']);

%Outputs
fprintf(fid,[ '*OUTPUT, FIELD  \n']);
fprintf(fid,[ '*Node Output \n']);
fprintf(fid,[ 'RF, U, UR \n']);

fprintf(fid,[ '*OUTPUT, FIELD   \n']);
fprintf(fid,[ '*Element Output  \n']);
fprintf(fid,[ 'SF  \n']);

%Print displacement
fprintf(fid,[ '*NODE PRINT, NSET=MIDNODE1, FREQUENCY=1, SUMMARY=NO   \n']);
fprintf(fid,[ 'U3 \n']);
fprintf(fid,[ 'CF3 \n']);

%End step
fprintf(fid,[ '**    \n']);
fprintf(fid,[ '**   \n']);
fprintf(fid,[ '*END STEP   \n']);


%% Run analysis
clc
JobName='Double_Model'
system(['abaqus job=' JobName ' input=double_model_abaqus interactive'])

pause(2)

winopen([ JobName '.odb']);
    
